@@ -1,11 +1,13 @@
+from types import CoroutineType
+
 class AbstractContextManager:
 
-    def __init__(self , coro):
+    def __init__(self , coro : CoroutineType):
         self._coro = coro
         self._obj = None
 
-    def __next__(self):
-        return self.send(None)
+    # def __next__(self):
+    #     return self.send(None)
 
     def __iter__(self):
         return self._coro.__await__()
